In the returned data frame each row represents a particular oceanographic or
meteorological measurement. The name of the measurement is provided in the
first column (Type). The second column, From, provides a
timestamp indicating the earliest available data for the measurement. The
third column, To, provides the last date and time when the
measurement is available. When there are gaps in availability there will be
two rows from a given measurement. See the table below as an example.
| Type |
From |
To |
|
Wind |
2011-06-10 21:06 |
2019-11-30 06:36 |
| Air Temperature
|
2011-06-10 20:48 |
2019-11-30 06:36 |
| Water Temperature |
2011-06-10 20:48 |
2013-03-10 03:48 |
| Water Temperature |
2015-04-03 13:06 |
2019-11-30 06:36 |
As of the release of version 0.20.0 there are thirteen stations where the
data inventory is missing and an Error will be returned if queried
with coops_station_inventory(). The list of stations without a data
inventory can be accessed by calling
noaaoceans:::known_missing_inventory(). Due to heavy use of JavaScript
on data inventory pages and a desire to keep package dependencies to a
minimum the list of known stations has been hard coded. Please create an
Issue or
Pull Request to update
the list stations missing data inventory.