Provides access to data available from NOAA's CO-OPS Derived Product API. Four derived data products are available through the API: 1) Top Ten Water Levels, 2) Annual Flood Days, 3) Extreme Water Levels and 4) Sea Level Trends. More detail about each data product is available with the API's documentation
query_derived_products(
station_id = NULL,
product_name = NULL,
year = NULL,
affil = NULL,
units = "english"
)an optional string that provides the a 7 character station id. If omitted the derived product API returns data for all stations.
a string providing the name of the derived data product.
Derived products include Top Ten Water Levels ('toptenwaterlevels'),
Annual Flood Days ('annualflooddays'), Extreme Water Levels
('extremewaterlevels') and Sea Level Trends ('sealeveltrends').
an optional string used to limit the results from the annual flood days product to the indicated year. The argument is ignored if used with other data products.
an optional argument used to limit the results from the Sea Level
Trends product to U.S. ('US') or Global stations ('Global').
If omitted with Sea Level Trends all stations are returned. The argument is
ignored if used with other data products.
a character string specifying if the data should be returned
using metric or English units. Defaults to 'english'
a data frame. See the documentation for the specific product for the details an it's content.
Results are returned as a data frame specific to each product. For the variables returned with each endpoint see the appropriate section in the documentation.
# NOT RUN {
# Not Run
query_derived_products(station_id = "1611400",
product_name = "sealeveltrends")
# }
Run the code above in your browser using DataLab